<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:lav="http://software.in2p3.fr/lavoisier/config.xsd"
                xmlns="http://software.in2p3.fr/lavoisier/config.xsd">
    <!-- This template creates a schema of the database -->
    <xsl:template match="lav:view-template[contains(@stylesheet,'SOAPTemplate.xsl')]">
        <xsl:variable name="prefix" select="substring-before(lav:parameter[@name='operation']/text(),':')"/>
        <xsl:variable name="namespace" select="lav:namespace[@prefix=$prefix]/@uri"/>
        <xsl:if test="not($namespace)">
            <xsl:message terminate="yes">View template '<xsl:value-of select="@stylesheet"/>' is missing namespace for prefix '<xsl:value-of
                    select="$prefix"/>'</xsl:message>
        </xsl:if>
        <xsl:variable name="operation" select="substring-after(lav:parameter[@name='operation']/text(),':')"/>
        <xsl:if test="not($operation)">
            <xsl:message terminate="yes">View template '<xsl:value-of select="@stylesheet"/>' is missing required parameter: operation</xsl:message>
        </xsl:if>
        <xsl:variable name="parameters">
            <xsl:choose>
                <xsl:when test="lav:parameter[@name='parameters']/@eval"><xsl:value-of select="lav:parameter[@name='parameters']/@eval"/></xsl:when>
                <xsl:otherwise>'<xsl:value-of select="lav:parameter[@name='parameters']/text()"/>'</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="SOAPHeader">
            <xsl:choose>
                <xsl:when test="lav:parameter[@name='SOAPHeader']/@eval"><xsl:value-of select="lav:parameter[@name='SOAPHeader']/@eval"/></xsl:when>
                <xsl:otherwise>'<xsl:value-of select="lav:parameter[@name='SOAPHeader']/text()"/>'</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <view><xsl:copy-of select="@*[not(local-name()='stylesheet')] | lav:*[not(self::lav:parameter)]"/>
            <connector type="HTTPConnector">
                <xsl:copy-of select="lav:parameter[@name='url']"/>
                <parameter name="header">
                    <entry key="Content-Type">text/xml; charset=ISO-8859-1</entry>
                    <entry key="SOAPAction">
                        <xsl:value-of select="$namespace"/>
                        <xsl:if test="substring($namespace,string-length($namespace)) != '/'">/</xsl:if>
                        <xsl:value-of select="$operation"/>
                    </entry>
                </parameter>
                <parameter name="post" eval="view('{@name}_soap', arguments())"/>
            </connector>
            <processors>
                <processor type="RemoveProcessor" match="/soapenv:Envelope">
                    <namespace prefix="soapenv" uri="http://schemas.xmlsoap.org/soap/envelope/"/>
                    <parameter name="depth">2</parameter>
                </processor>
            </processors>
        </view>
        <view name="{@name}_soap"><xsl:copy-of select="lav:*[not(self::lav:parameter)]"/>
            <connector type="XMLConnector">
                <parameter name="content" eval="concat(
'&lt;SOAP-ENV:Envelope xmlns:SOAP-ENV=&quot;http://schemas.xmlsoap.org/soap/envelope/&quot;>',
    '&lt;SOAP-ENV:Header>',
        string({$SOAPHeader}),
    '&lt;/SOAP-ENV:Header>',
    '&lt;SOAP-ENV:Body>',
        '&lt;{$operation} xmlns=&quot;{$namespace}&quot;>',
            string({$parameters}),
        '&lt;/{$operation}>',
    '&lt;/SOAP-ENV:Body>',
'&lt;/SOAP-ENV:Envelope>'
)"/>
            </connector>
        </view>
    </xsl:template>
</xsl:stylesheet>