<!-- others.xsl -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:e="http://software.in2p3.fr/lavoisier/entries.xsd"
                xmlns:cfg="http://software.in2p3.fr/lavoisier/config.xsd">
    <xsl:output method="html"/>

    <xsl:variable name="confView" select="document('conf_view')"/>
    <xsl:variable name="statusView" select="document('status_view')"/>
    <xsl:variable name="navbarView" select="document('navbar_view')"/>
    <xsl:variable name="headView" select="document('head_view')"/>
    <xsl:key name="cat_id" match="cfg:category" use="."/>
    <xsl:variable name="defaultCatLabel" select="'No category'"/>

    <xsl:template match="/">
        <html>
            <xsl:copy-of select="$headView"/>
            <body>
                <xsl:copy-of select="$navbarView"/>
                <xsl:variable name="catMatch"
                              select="$confView/cfg:config/cfg:view[not(cfg:info/cfg:category/text() = /menu/item/@category or cfg:info/cfg:category/text() = 'Hidden' or cfg:info/cfg:category/text() = false()) or not(cfg:info/cfg:category)]"/>
                <xsl:variable name="catNoMatch"
                              select="$confView/cfg:config/cfg:view[not(cfg:info/cfg:category/text() = /menu/item/@category or cfg:info/cfg:category/text() = 'Hidden') and (not(cfg:info/cfg:category) or not(cfg:info/cfg:category/text()))]"/>
                <div class="container bs-docs-container">
                    <div class="row">
                        <div class="col-md-2">
                            <div class="bs-docs-sidebar hidden-print affix">
                                <ul class="nav bs-docs-sidenav">
                                    <xsl:if test="$catNoMatch">
                                        <xsl:call-template name="menuItem">
                                            <xsl:with-param name="itemName" select="$defaultCatLabel"/>
                                        </xsl:call-template>
                                    </xsl:if>
                                    <xsl:apply-templates select="$catMatch" mode="catList"/>
                                </ul>
                            </div>
                        </div>
                        <div class="col-md-10" role="main">
                            <xsl:apply-templates select="$catMatch" mode="catView"/>
                            <xsl:if test="$catNoMatch">
                                <section>
                                    <xsl:attribute name="id">
                                        <xsl:value-of select="$defaultCatLabel"/>
                                    </xsl:attribute>
                                    <div class="page-header">
                                        <h1>
                                            <small>
                                                <xsl:value-of select="$defaultCatLabel"/>
                                            </small>
                                        </h1>
                                    </div>
                                    <table class="table table-bordered table-striped">
                                        <xsl:call-template name="tHead"/>
                                        <tbody>
                                            <xsl:for-each select="$catNoMatch">
                                                <xsl:apply-templates select="." mode="viewRow"/>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </section>
                            </xsl:if>
                        </div>
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>

    <!-- left category menu -->
    <xsl:template match="cfg:view" mode="catList">
        <xsl:if test="(generate-id(cfg:info/cfg:category)=generate-id(key('cat_id', cfg:info/cfg:category)[1]) and cfg:info/cfg:category and cfg:info/cfg:category/text()) ">
            <xsl:call-template name="menuItem">
                <xsl:with-param name="itemName" select="cfg:info/cfg:category/text()"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <!-- left category item menu -->
    <xsl:template name="menuItem">
        <xsl:param name="itemName"/>
        <li>
            <a>
                <xsl:attribute name="href">
                    #<xsl:value-of select="$itemName"/>
                </xsl:attribute>
                <xsl:value-of select="$itemName"/>
                <i class="glyphicon glyphicon-chevron-right"></i>
            </a>
        </li>
    </xsl:template>

    <!-- category & view list section -->
    <xsl:template match="cfg:view" mode="catView">
        <xsl:if test="(generate-id(cfg:info/cfg:category)=generate-id(key('cat_id', cfg:info/cfg:category)[1]) and cfg:info/cfg:category and cfg:info/cfg:category/text() )">
            <xsl:variable name="catName" select="cfg:info/cfg:category/text()"/>
            <div class="bs-docs-section">
                <xsl:attribute name="id">
                    <xsl:value-of select="$catName"/>
                </xsl:attribute>
                <div class="page-header">
                    <h2>
                        <xsl:value-of select="$catName"/>
                    </h2>
                </div>
                <table class="table table-bordered table-striped">
                    <xsl:call-template name="tHead"/>
                    <tbody>
                        <xsl:apply-templates
                                select="$confView/cfg:config/cfg:view[cfg:info/cfg:category/text() = $catName]"
                                mode="viewRow"/>
                    </tbody>
                </table>
            </div>
        </xsl:if>
    </xsl:template>

    <!-- table head -->
    <xsl:template name="tHead">
        <thead>
            <tr>
                <th>name</th>
                <th>status</th>
                <th>description</th>
                <th>arguments</th>
                <th>others</th>
            </tr>
        </thead>
    </xsl:template>

    <!--  view as a row -->
    <xsl:template match="cfg:view" mode="viewRow">

        <!-- if view not already treated -->
        <xsl:variable name="viewName" select="@name"/>
        <xsl:variable name="statusNode" select="$statusView/jmx/domain/group/mbean[@name=$viewName]"/>
        <tr>
            <td>
                <a title="see view with default rendering" href="/lavoisier/form/{$viewName}">
                    <xsl:choose>
                        <xsl:when test="not(cfg:info/cfg:label/text())">
                            <xsl:value-of select="$viewName"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="cfg:info/cfg:label"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </a>
                <xsl:if test="not(cfg:argument[not(@eval or text()!='')])">
                    <a title="Bypass form">
                        <xsl:attribute name="href">/lavoisier/<xsl:value-of select="$viewName"/>
                            <xsl:for-each select="cfg:info/cfg:accept">?accept=<xsl:value-of select="text()"/></xsl:for-each>
                        </xsl:attribute><xsl:text>   </xsl:text>
                        <i class='glyphicon glyphicon-share'> </i>
                    </a>
                </xsl:if>
            </td>
            <td>
                <a title="see information about the status of the view">
                    <xsl:attribute name="href">
                        /lavoisier/status/jmx/domain/group/mbean[@name='<xsl:value-of select="$viewName"/>']
                    </xsl:attribute>
                    <xsl:choose>
                        <xsl:when test="$statusNode/attribute[@name='CurrentBuildStartDate']/value/text()!='null'">
                            <span class="label label-info">Currently building</span>
                        </xsl:when>
                        <xsl:when test="$statusNode/attribute[@name='LastException']/value/text()!='null'">
                            <span class="label label-warning">Exception raised</span>
                        </xsl:when>
                        <xsl:when test="$statusNode/attribute[@name='LastBuildDate']/value/text()='null'">
                            <span class="label label-default">Not built yet</span>
                        </xsl:when>
                        <xsl:otherwise>
                            <span class="label label-success">Successfully built</span>
                        </xsl:otherwise>
                    </xsl:choose>
                </a>
            </td>
            <td>
                <xsl:value-of select="cfg:info/cfg:description/text()"/>
            </td>
            <td>
                <xsl:for-each select="cfg:argument">
                    <ul style="list-style-type: none; margin: 0; padding: 0">
                        <li>
                            <xsl:choose>
                                <xsl:when test="@eval">
                                    <b><xsl:value-of select="@name"/></b>: ?
                                </xsl:when>
                                <xsl:when test="text() != ''">
                                    <b><xsl:value-of select="@name"/></b>: <xsl:value-of select="text()"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <font color="red">
                                        <b><xsl:value-of select="@name"/></b>
                                    </font>
                                </xsl:otherwise>
                            </xsl:choose>
                            <xsl:if test="@pattern != '[^/]*'">
                                <i> (<xsl:value-of select="@pattern"/>)</i>
                            </xsl:if>
                        </li>
                    </ul>
                </xsl:for-each>
                <xsl:if test="cfg:argument[not(@path-format = 'none')]">
                    <span class="badge">
                        <xsl:for-each select="cfg:argument">
                            <xsl:if test="@path-format = 'name_value'">
                                <xsl:text>/</xsl:text>
                                <xsl:value-of select="@name"/>
                            </xsl:if>
                            <xsl:if test="not(@path-format = 'none')">
                                <xsl:text>/{</xsl:text>
                                <xsl:value-of select="@name"/>
                                <xsl:if test="text() != ''">
                                    <xsl:text>=</xsl:text>
                                    <xsl:value-of select="text()"/>
                                </xsl:if>
                                <xsl:text>}</xsl:text>
                            </xsl:if>
                        </xsl:for-each>
                    </span>
                </xsl:if>
            </td>
            <td>
                <a title="see configuration of this view" href="/lavoisier/debug/{$viewName}">
                    <i class='glyphicon glyphicon-tasks'> </i>
                </a>
                |
                <a title="see execution plans of this view" href="/lavoisier/configuration/cfg:config/cfg:view[@name='{$viewName}']">
                    <i class='glyphicon glyphicon-cog'> </i>
                </a>
                <xsl:if test="cfg:cache/cfg:trigger[@type='fr.in2p3.lavoisier.trigger.ViewNotifiedTrigger']">
                    |
                    <a title="force cache refresh" href="#">
                        <xsl:attribute name="onclick">
                            $.ajax({ url: '/notify/<xsl:value-of select="$viewName"/>', context: document.body }).complete(function() {alert('view notified:  <xsl:value-of select="$viewName"/>'); });
                        </xsl:attribute>
                        <i class='glyphicon glyphicon-refresh'> </i>
                    </a>
                </xsl:if>
            </td>

        </tr>
    </xsl:template>
</xsl:stylesheet>
